@@ -8,7 +8,7 @@ sub hello {
 
 $window = new Gtk::Widget	"GtkWindow",
 		GtkObject::user_data		=>	undef,
-		GtkWindow::type			=>	0,
+		GtkWindow::type			=>	-toplevel,
 		GtkWindow::title		=>	"hello world",
 		GtkWindow::allow_grow		=>	0,
 		GtkWindow::allow_shrink		=>	0,
